@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2002-2008 Jeremy Laine
+ * Copyright (C) 1993-2009 Robert & Jeremy Laine
+ * See AUTHORS file for a full list of contributors.
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -190,16 +191,21 @@ public:
     {
         return 0.5 * (min + max);
     };
+
+    CRect3d expandToRatio(const real ratio) const;
+
     /** Return the box's width. */
     real width() const
     {
         return max.x()-min.x();
     };
+
     /** Return the box's height. */
     real height() const
     {
         return max.y()-min.y();
     };
+
     CRect3d join(const CRect3d& rect) const;
 
     /** lower-left corner */
