@@ -1,17 +1,17 @@
 /*
- * Copyright (C) 1993-2008 Robert & Jeremy Laine
+ * Copyright (C) 1993-2009 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
- *
+ * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- *
+ * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -19,21 +19,21 @@
 
 #include "sailprinter.h"
 
+#include <QDebug>
 #include <QPrinter>
 
-#include "sailcalc.h"
-#include "saildef.h"
-#include "panelgroup.h"
-#include "sailcalc.h"
+#include "sailcpp/sailcalc.h"
+#include "sailcpp/saildef.h"
+#include "sailcpp/panelgroup.h"
+#include "sailcpp/sailcalc.h"
 
 
-/**
- * Print the current sail data.
+/** Print the current sail data sheet.
  *
  * @param painter
  * @param fontsize
  */
-void CSailDataPrinter::print(CTextPainter *painter, int, real fontsize) const
+void CSailDataPrinter::print(CTextPainter *painter, int, real scale, real fontsize) const
 {
     QString text2=" ", text3=" ";
     painter->setFontSize(fontsize, 1);
@@ -152,60 +152,86 @@ void CSailDataPrinter::print(CTextPainter *painter, int, real fontsize) const
 }
 
 
-/** Print a developed sail.
+/** Print a developed sail panel by panel.
  *
  * @param painter
  * @param page
+ * @param scale
  * @param fontsize
  */
-void CSailDevelPrinter::print(CTextPainter *painter, int page, real fontsize) const
+void CSailDevelPrinter::print(CTextPainter *painter, int page, real scale, real fontsize) const
 {
-    // calculate logical rectangle
-    real zoom = 0.8;
-    CRect3d flatrect = flatsail.boundingRect();
-    CRect3d logicalRect = calcLRect(painter->viewRect(), flatrect, flatrect.center(), zoom);
+    // set scale
+    CRect3d logicalRect = CRect3d(CPoint3d(0, 0, 0), CPoint3d(painter->device()->widthMM(), painter->device()->heightMM(), 0)) * (1/scale);
+
+    // center view
+    logicalRect = logicalRect + (sail.boundingRect().center() - logicalRect.center());
 
     // set coordinate system to match the logical viewport
     painter->setWindow(logicalRect);
-    painter->setFontSize(fontsize, zoom);
+    painter->setFontSize(fontsize, 1);
 
-    painter->draw(flatsail[page]);
+    painter->draw(sail[page]);
     if (showLabels)
-        painter->drawLabels(flatsail[page]);
+        painter->drawLabels(sail[page]);
 
-    painter->drawMarkers(flatsail[page]);
+    painter->drawMarkers(sail[page]);
 
     // mark corners of cloth rectangle
     QPen oldpen = painter->pen();
     painter->setPen(Qt::green);
-    CRect3d rp = flatsail[page].boundingRect();
+    CRect3d rp = sail[page].boundingRect();
     painter->drawCross(rp.min, painter->fontMetrics().height() );
     painter->drawCoord(rp.min, PI );
     painter->setPen(oldpen);
+
+    /* NOTE scale factor on preview screen is not same value as in spinbox
+    *  However the correct value equal to spinbox value will be printed */
+    QString txt = tr("Scale")+" = %1";
+    txt = txt.arg(scale, 0, 'f', 3);
+    CPoint3d pt = logicalRect.center()+ CVector3d(0,1,0)*0.47*logicalRect.height();
+    painter->drawTextCentered(pt, txt);
 }
 
 
-/** Print the drawing of a sail.
+/** Print the drawing of a complete sail.
  *
  * @param painter
+ * @param scale
  * @param fontsize
  */
-void CSailDrawingPrinter::print(CTextPainter *painter, int, real fontsize) const
+void CSailDrawingPrinter::print(CTextPainter *painter, int, real scale, real fontsize) const
 {
-    // center the sail
-    CPanelGroup printSail = sail + CVector3d( -sail.boundingRect().center() );
+    // set scale
+    CRect3d logicalRect = CRect3d(CPoint3d(0, 0, 0), CPoint3d(painter->device()->widthMM(), painter->device()->heightMM(), 0)) * (1/scale);
 
-    // calculate logical rectangle
-    real zoom = 0.8;
-    CRect3d logicalRect = calcLRect(painter->viewRect(), printSail.boundingRect(), CPoint3d(0,0,0), zoom);
+    // center view
+    logicalRect = logicalRect + (sail.boundingRect().center() - logicalRect.center());
 
     // set coordinate system to match the logical viewport
     painter->setWindow(logicalRect);
-    painter->setFontSize(fontsize, zoom);
-
-    painter->draw(printSail);
+    painter->setFontSize(fontsize, 1);
+    
+    painter->draw(sail);
     if (showLabels)
-        painter->drawLabels(printSail);
+        painter->drawLabels(sail);
+
+    /* NOTE scale factor on preview screen is not same value as in spinbox
+    *  However the correct value equal to spinbox value will be printed */
+    QString txt = tr("Scale")+" = %1";
+    txt = txt.arg(scale, 0, 'f', 3);
+    CPoint3d pt = logicalRect.center()+ CVector3d(0,1,0)*0.47*logicalRect.height();
+    painter->drawTextCentered(pt, txt);
 }
 
-
+/** Return the scale needed to fit the developed sail in the given device.
+ *
+ * @param device
+ */
+double CSailDrawingPrinter::scaleToFit(QPaintDevice* device) const
+{
+    Q_ASSERT(device->widthMM() > 0 && device->heightMM() > 0);
+    const real w = device->widthMM();
+    const real h = device->heightMM();
+    return 0.8 * w / sail.boundingRect().expandToRatio(w / h).width();
+}
\ No newline at end of file
