@@ -1,25 +1,25 @@
 /*
- * Copyright (C) 1993-2008 Robert & Jeremy Laine
+ * Copyright (C) 1993-2009 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
- *
+ * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- *
+ * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include "widgetprofilevert.h"
-#include "sailcalc.h"
-#include "sailmould.h"
+#include "sailcpp/sailcalc.h"
+#include "sailcpp/sailmould.h"
 
 #include <QGroupBox>
 #include <QLayout>
@@ -45,7 +45,7 @@ CLabelProfileVert::CLabelProfileVert( QWidget *parent, CSailMould *ptr)
     pal.setColor( QPalette::Background, Qt::white );
     setPalette( pal );
 
-    setMinimumSize( QSize( 110, 400 ) );
+    setMinimumSize( QSize( 120, 400 ) );
 }
 
 
@@ -59,7 +59,7 @@ void CLabelProfileVert::paintEvent( QPaintEvent *)
     painter.eraseRect(vRect);
 
     CRect3d objRect;
-    objRect.max = CPoint3d(0.2, 1);
+    objRect.max = CPoint3d(0.22, 1);
 
     if ( wasResized )
     {
